@@ -25,6 +25,10 @@ pub enum GeozeroError {
     // PropertyProcessor
     #[error("processing feature property: `{0}`")]
     Property(String),
+    #[error("column not found or null")]
+    ColumnNotFound,
+    #[error("expected a `{0}` value but found `{1}`")]
+    ColumnType(String, String),
     // GeometryProcessor
     #[error("accessing requested coordinate")]
     Coord,
